@@ -1,48 +1,53 @@
-( cd opt/kde/lib ; rm -rf libkomparediff2.so.4 )
-( cd opt/kde/lib ; ln -sf libkomparediff2.so.4.2.0 libkomparediff2.so.4 )
-( cd opt/kde/lib ; rm -rf libkstartperf.so )
-( cd opt/kde/lib ; ln -sf libkstartperf.so.4 libkstartperf.so )
-( cd opt/kde/lib ; rm -rf libkateinterfaces.so.4 )
-( cd opt/kde/lib ; ln -sf libkateinterfaces.so.4.2.0 libkateinterfaces.so.4 )
-( cd opt/kde/lib ; rm -rf libkomparediff2.so )
-( cd opt/kde/lib ; ln -sf libkomparediff2.so.4 libkomparediff2.so )
-( cd opt/kde/lib ; rm -rf libantlr.so.4 )
-( cd opt/kde/lib ; ln -sf libantlr.so.4.2.0 libantlr.so.4 )
-( cd opt/kde/lib ; rm -rf libkompareinterface.so.4 )
-( cd opt/kde/lib ; ln -sf libkompareinterface.so.4.2.0 libkompareinterface.so.4 )
-( cd opt/kde/lib ; rm -rf libkomparedialogpages.so.4 )
-( cd opt/kde/lib ; ln -sf libkomparedialogpages.so.4.2.0 libkomparedialogpages.so.4 )
-( cd opt/kde/lib ; rm -rf libktrace.so.4 )
-( cd opt/kde/lib ; ln -sf libktrace.so.4.2.0 libktrace.so.4 )
-( cd opt/kde/lib ; rm -rf libkstartperf.so.4 )
-( cd opt/kde/lib ; ln -sf libkstartperf.so.4.2.0 libkstartperf.so.4 )
-( cd opt/kde/lib ; rm -rf libkomparedialogpages.so )
-( cd opt/kde/lib ; ln -sf libkomparedialogpages.so.4 libkomparedialogpages.so )
-( cd opt/kde/lib ; rm -rf libkompareinterface.so )
-( cd opt/kde/lib ; ln -sf libkompareinterface.so.4 libkompareinterface.so )
-( cd opt/kde/lib ; rm -rf libktrace.so )
-( cd opt/kde/lib ; ln -sf libktrace.so.4 libktrace.so )
-( cd opt/kde/lib ; rm -rf libantlr.so )
-( cd opt/kde/lib ; ln -sf libantlr.so.4 libantlr.so )
-( cd opt/kde/lib ; rm -rf libkateinterfaces.so )
-( cd opt/kde/lib ; ln -sf libkateinterfaces.so.4 libkateinterfaces.so )
-( cd opt/kde/share/doc/HTML/en/kate ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kate ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/cervisia ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/cervisia ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/lokalize ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/lokalize ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/umbrello ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/umbrello ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kate-plugins ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kompare ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcachegrind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kate ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kate ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kapptemplate ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kapptemplate ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/cervisia ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/cervisia ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kdesvn-build ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kdesvn-build ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kapptemplate ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kapptemplate ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/lokalize ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/lokalize ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kate-plugins ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/umbrello ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/umbrello ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/lib ; rm -rf libkomparedialogpages.so.4 )
+( cd opt/kde/lib ; ln -sf libkomparedialogpages.so.4.3.0 libkomparedialogpages.so.4 )
+( cd opt/kde/lib ; rm -rf libktrace.so )
+( cd opt/kde/lib ; ln -sf libktrace.so.4 libktrace.so )
+( cd opt/kde/lib ; rm -rf libkateinterfaces.so )
+( cd opt/kde/lib ; ln -sf libkateinterfaces.so.4 libkateinterfaces.so )
+( cd opt/kde/lib ; rm -rf libantlr.so )
+( cd opt/kde/lib ; ln -sf libantlr.so.4 libantlr.so )
+( cd opt/kde/lib ; rm -rf libkstartperf.so.4 )
+( cd opt/kde/lib ; ln -sf libkstartperf.so.4.3.0 libkstartperf.so.4 )
+( cd opt/kde/lib ; rm -rf libkateinterfaces.so.4 )
+( cd opt/kde/lib ; ln -sf libkateinterfaces.so.4.3.0 libkateinterfaces.so.4 )
+( cd opt/kde/lib ; rm -rf libktrace.so.4 )
+( cd opt/kde/lib ; ln -sf libktrace.so.4.3.0 libktrace.so.4 )
+( cd opt/kde/lib ; rm -rf libkomparedialogpages.so )
+( cd opt/kde/lib ; ln -sf libkomparedialogpages.so.4 libkomparedialogpages.so )
+( cd opt/kde/lib ; rm -rf libkompareinterface.so.4 )
+( cd opt/kde/lib ; ln -sf libkompareinterface.so.4.3.0 libkompareinterface.so.4 )
+( cd opt/kde/lib ; rm -rf libkomparediff2.so )
+( cd opt/kde/lib ; ln -sf libkomparediff2.so.4 libkomparediff2.so )
+( cd opt/kde/lib ; rm -rf libkstartperf.so )
+( cd opt/kde/lib ; ln -sf libkstartperf.so.4 libkstartperf.so )
+( cd opt/kde/lib ; rm -rf libantlr.so.4 )
+( cd opt/kde/lib ; ln -sf libantlr.so.4.3.0 libantlr.so.4 )
+( cd opt/kde/lib ; rm -rf libkomparediff2.so.4 )
+( cd opt/kde/lib ; ln -sf libkomparediff2.so.4.3.0 libkomparediff2.so.4 )
+( cd opt/kde/lib ; rm -rf libkompareinterface.so )
+( cd opt/kde/lib ; ln -sf libkompareinterface.so.4 libkompareinterface.so )
+#%% begin initialize kdesdk-4.3.1
+if [ -f /opt/kde/bin/plamo_update_kde.sh ]; then
+	/bin/bash /opt/kde/bin/plamo_update_kde.sh
+fi
+#%% end
